@@ -22,6 +22,10 @@ struct omp_nest_lock {
 };
 typedef struct omp_nest_lock omp_nest_lock_t;
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 extern void omp_set_num_threads(int n);
 extern int omp_get_thread_num(void);
 extern int omp_get_num_procs(void);
@@ -43,3 +47,6 @@ extern void omp_set_nest_lock(omp_nest_lock_t *s);
 extern void omp_unset_nest_lock(omp_nest_lock_t *s);
 extern int omp_test_nest_lock(omp_nest_lock_t *s);
 
+#ifdef __cplusplus
+}
+#endif
