@@ -1,7 +1,7 @@
 /* 
 * stdarg.h
 *
-*      Copyright 1995, The Portland Group, Incorporated.
+*      Copyright 1995-2000, The Portland Group, Incorporated.
 *      All rights reserved.
 *
 *        THE PORTLAND GROUP, INCORPORATED PROPRIETARY INFORMATION
@@ -28,7 +28,14 @@ typedef void *__gnuc_va_list;
 
 #endif
 
+#ifndef _VARARGS_H
 typedef char *va_list;
+#else
+/* remove varargs.h's defines of the va_... macros */
+#undef va_start
+#undef va_end
+#undef va_arg
+#endif
 
 #define va_start(list, param) list = (char *)__builtin_va_start(&param)
 
