@@ -1,7 +1,7 @@
 /* 
 * varargs.h
 *
-*      Copyright 1995, The Portland Group, Incorporated.
+*      Copyright 1995-2000, The Portland Group, Incorporated.
 *      All rights reserved.
 *
 *        THE PORTLAND GROUP, INCORPORATED PROPRIETARY INFORMATION
@@ -21,7 +21,14 @@ extern int   __builtin_va_arg_size(...);
 
 #endif /* __cplusplus */
 
+#ifndef _STDARG_H
 typedef char *va_list;
+#else
+/* remove stdarg.h's defines of the va_... macros */
+#undef va_start
+#undef va_end
+#undef va_arg
+#endif
 
 #ifdef __cplusplus
 /* get the C++ correct prototype style */
